summaryrefslogtreecommitdiff
path: root/src/vm/interoputil.h
diff options
context:
space:
mode:
authorSwaroop Sridhar <Swaroop.Sridhar@microsoft.com>2019-01-18 09:24:41 -0800
committerGitHub <noreply@github.com>2019-01-18 09:24:41 -0800
commit732f892665343e84d04eea4478eccb459b385f55 (patch)
treea76fa9e8df71b776e414a0e73079974cf849d02b /src/vm/interoputil.h
parentec53bfdc54cf1b79730561c4a7f3c744090a400c (diff)
downloadcoreclr-732f892665343e84d04eea4478eccb459b385f55.tar.gz
coreclr-732f892665343e84d04eea4478eccb459b385f55.tar.bz2
coreclr-732f892665343e84d04eea4478eccb459b385f55.zip
Add Per-assembly Load Native Library callbacks (#21555)
Add Per-assembly Load Native Library callbacks This Change implements the Native Library resolution Call-backs proposed in https://github.com/dotnet/corefx/issues/32015
Diffstat (limited to 'src/vm/interoputil.h')
-rw-r--r--src/vm/interoputil.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/vm/interoputil.h b/src/vm/interoputil.h
index 91f6828c49..872848b9df 100644
--- a/src/vm/interoputil.h
+++ b/src/vm/interoputil.h
@@ -136,9 +136,9 @@ void FillExceptionData(
_In_opt_ IRestrictedErrorInfo* pRestrictedErrorInfo);
//---------------------------------------------------------------------------
-//returns true if pImport has DefaultDllImportSearchPathsAttribute
-//if true, also returns dllImportSearchPathFlag and searchAssemblyDirectory values.
-BOOL GetDefaultDllImportSearchPathsAttributeValue(IMDInternalImport *pImport, mdToken token, DWORD * pDlImportSearchPathFlag);
+// If pImport has the DefaultDllImportSearchPathsAttribute,
+// set the value of the attribute in pDlImportSearchPathFlags and return true.
+BOOL GetDefaultDllImportSearchPathsAttributeValue(IMDInternalImport *pImport, mdToken token, DWORD * pDlImportSearchPathFlags);
//---------------------------------------------------------------------------
// Returns the index of the LCID parameter if one exists and -1 otherwise.